{% extends 'dedal/base.html' %}

{% load i18n dedal_tags %}

{% block content %}
	<h2>
		{{ model|verbose_name_plural|title }}
		<a class="btn btn-success" href="{% crud model 'create' %}" title="{% blocktrans %}Create {{ verbose_name }}{% endblocktrans %}">
			<span class="glyphicon glyphicon-plus" aria-hidden="true"></span>
		</a>
	</h2>
	<ul class="list-group">
		{% for object in object_list %}
			<li class="list-group-item">
				<a href="{% crud object 'read' %}">{{ object }}</a>
				<div class="pull-right">
					<a class="btn btn-primary btn-xs" href="{% crud object 'update' %}">
						<span class="glyphicon glyphicon-pencil" aria-hidden="true"></span>
						{% trans 'Update' %}
					</a>
					<a class="btn btn-danger btn-xs" href="{% crud object 'delete' %}">
						<span class="glyphicon glyphicon-trash" aria-hidden="true"></span>
						{% trans 'Delete' %}
					</a>
				</div>
			</li>
		{% empty %}
			<p>{% trans 'Nothing to display.' %}</p>
		{% endfor %}
	</ul>
{% endblock %}
