{% extends 'dedal/base.html' %}

{% load i18n dedal_tags %}

{% block content %}
	<h2>
		{{ object }}
		<span class="small">id: {{ object.pk }}</span>
		<a class="btn btn-primary" href="{% crud object 'list' %}">
			<span class="glyphicon glyphicon-chevron-left" aria-hidden="true"></span> {% trans 'Back to' %} {{ object|verbose_name_plural }}
		</a>
	</h2>
	<dl>
	{% for name, value in fields.items %}
		<dt>{{ name }}</dt>
		<dd>{{ value }}</dd>
	{% endfor %}
		<a class="btn btn-primary" href="{% crud object 'update' %}">{% trans 'Update' %}</a>
		<a class="btn btn-danger" href="{% crud object 'delete' %}">
			<span class="glyphicon glyphicon-trash" aria-hidden="true"></span> {% trans 'Delete' %}
		</a>
{% endblock %}
